@@ -1907,9 +1907,9 @@ open_result_from_list(GtkTreeView* tree_view,
       {
 	OssoABookContact *original_contact = (OssoABookContact*)entries->data;
 	const char* n = osso_abook_contact_get_name(original_contact);
-	GtkWidget* dialog = osso_abook_touch_contact_starter_dialog_new
-	  (GTK_WINDOW(self),
-	   ( OssoABookTouchContactStarter*)osso_abook_touch_contact_starter_new_with_contact(GTK_WINDOW(self), original_contact));
+	GtkWidget* contact_starter = osso_abook_touch_contact_starter_new_with_editor(GTK_WINDOW(self), original_contact);
+	GtkWidget* dialog = osso_abook_touch_contact_starter_dialog_new(GTK_WINDOW(self),
+									OSSO_ABOOK_TOUCH_CONTACT_STARTER(contact_starter));
 	gtk_widget_show_all(dialog);
       }
       g_list_free(entries);
@@ -1952,7 +1952,8 @@ _read_settings(ScoutWindow* self)
     g_object_unref(client);
     return;
   }
-  self->priv->search_in_contacts = gconf_client_get_bool(client, GCONF_SEARCH_CONTACTS, NULL);
+  GError* error = NULL;
+  self->priv->search_in_contacts = gconf_client_get_bool(client, GCONF_SEARCH_CONTACTS, &error);
   self->priv->search_in_conversations = gconf_client_get_bool(client, GCONF_SEARCH_CONVERSATIONS , NULL);
   self->priv->search_in_calendars = gconf_client_get_bool(client, GCONF_SEARCH_CALENDARS , NULL);
   self->priv->search_case_sensitive = gconf_client_get_bool(client, GCONF_SEARCH_CASE_SENSITIVE, NULL);
